@@ -1,4 +1,5 @@
 from model import (
     ModelObjective, 
-    ModelName
+    ModelName,
+    OptimizerType
 )
\ No newline at end of file
